set more off
clear all



global path ""

cap log close
log using "${path}/log/200_mult_regr.log", replace

cap log close logl
log using "${path}/out/200_mult_regr.log", name(logl) replace
log off logl

cap log close logiia
log using "${path}/out/200_IIA.log", name(logiia) replace
log off logiia

***********************************************************************************
*     200_mult_regr.do           START
***********************************************************************************

use "${path}/work\100_renset_data.dta", clear

gen a1v = parti==1
gen a2c = parti==2
gen a3h = parti==3

summ

gen alde2 = alder^2

save "${path}/work\200_reg_data.dta", replace

***********************************************************************************
* Multinomial logistisk regression
***********************************************************************************
preserve
keep parti kvind alder alde2
for var parti kvind alder alde2: gen zX=X
drop parti kvind alder alde2
rename zparti parti
rename zkvind kvind
rename zalder alder
rename zalde2 alde2
outsheet using "${path}/work\200_reg_data.csv", comma replace
restore

mlogit parti i.kvind alder alde2

fitstat

test [2_Centru]alder [2_Centru]alde2
test [2_Centru]alder
test [2_Centru]alde2


margins, dydx(*)

preserve
replace kvind=1
predict p1_kvin p2_kvin p3_kvin
replace kvind=0
predict p1_mand p2_mand p3_mand
gen p1_kvin_eff = p1_kvin - p1_mand
gen p2_kvin_eff = p2_kvin - p2_mand
gen p3_kvin_eff = p3_kvin - p3_mand
summ p*_kvin_eff
restore

log on logl
margins, dydx(*)
margins, dydx(*) pr(out(2))
margins, dydx(*) pr(out(3))
log off logl

***********************************************************************************
* Predikterede ssh og KI samt plot
***********************************************************************************
margins kvind, predict(outc(1))
marginsplot, name(g1) title("1. Rd blok") ytitle("") xtitle("")
margins kvind, predict(outc(2))
marginsplot, name(g2) title("2. Centrum") ytitle("") xtitle("")
margins kvind, predict(outc(3))
marginsplot, name(g3) title("3. Bl blok") ytitle("") xtitle("")
graph combine g1 g2 g3, ycommon cols(3) xsize(20) ysize(7.5)
graph export "${path}/out/200_10_KI.emf", as(emf) replace

***********************************************************************************
* Predikterede sandsynligheder P(Y=j)
***********************************************************************************
predict p1v p2c p3h
summ p1v p2c p3h

sort kvind alder

for var a1v a2c a3h: gen x_X = X

summ a1-a3 x_a*

tab x_a1v, miss

collapse a1v a2c a3h p1v p2c p3h (sum) x_a1v x_a2c x_a3h, by(kvind alder)

summ a1-a3 x_a*

preserve
keep if kvind==0

twoway ///
(scatter a1v alder [w=x_a1v], msize(0.3 ) mc(gs12)) ///
(line    p1v alder          ,             lc(gs12)) ///
(scatter a2c alder [w=x_a2c], msize(0.3 ) mc(gs8)) ///
(line    p2c alder          ,             lc(gs8)) ///
(scatter a3h alder [w=x_a3h], msize(0.3 ) mc(black)) ///
(line    p3h alder          ,             lc(black)), ///
legend(off) name(male) title(A. Mnd)
restore

preserve
keep if kvind==1

twoway ///
(scatter a1v alder [w=x_a1v], msize(0.3 ) mc(gs12)) ///
(line    p1v alder          ,             lc(gs12)) ///
(scatter a2c alder [w=x_a2c], msize(0.3 ) mc(gs8)) ///
(line    p2c alder          ,             lc(gs8)) ///
(scatter a3h alder [w=x_a3h], msize(0.3 ) mc(black)) ///
(line    p3h alder          ,             lc(black)), ///
legend(off) name(fema) title(B. Kvinder)
restore

graph combine male fema, rows(2)  xsize(9) ysize(12)
graph export "${path}/out/200_20_male_fema.emf", as(emf) replace

********************************************************************************
* IIA-test. Base er 3 (Bl blok), 2 er udeladt
********************************************************************************

log on logiia

use "${path}/work\200_reg_data.dta", clear

mlogit parti i.kvind alder alde2, base(3)
estimates store alle

mlogit parti i.kvind alder alde2 if parti!=2, base(3)
estimates store partiel

suest partiel alle
test ///
([partiel_1_Ve_ori]1.kvind=[alle_1_Ve_ori]1.kvind) ///
([partiel_1_Ve_ori]alder  =[alle_1_Ve_ori]alder)   ///
([partiel_1_Ve_ori]alde2  =[alle_1_Ve_ori]alde2)   ///
([partiel_1_Ve_ori]_cons  =[alle_1_Ve_ori]_cons)

log off logiia

***********************************************************************************
*     200_mult_regr.do           END
***********************************************************************************
cap log close
