use ekspropriering, clear

keep ex1 aid oilcap polconiii w y4-y7 ccid period

* Datastruktur
	xtset ccid period /* denne kommando fortæller Stata, at vi har at gøre med panel data (rum: ccid; tid: period) */
	
	xtdescribe if period>=4 /* beskrivelse af de to niveauer i datasættet */

* Eksempel 1: Lineær regression med tidsdummyer 
	reg ex1 aid oilcap polconiii w i.period if period>=4, cluster(ccid)
	testparm i.period /* kollektiv F-test af periodedummyer */
	
	lincom _b[6.period] - _b[5.period] /* test af forskel mellem de to sidste perioder */
	margins, over(period) at(aid=0 oilcap=0 polconiii=0 w=0) /* forudsagt gennemsnitlig Y for tidsperioder */ 

* Eksempel 2: First-differencing
	* Illustration af FD
		ta period if period==5 | period==6, s(ex1)
		di .85282052 - .62452992 /* risiko for ekspropriation (ex1) stiger med 0,23 fra periode 5 til 6 */
	
		reg d.ex1 if period==6 /* denne ændring opfanges i interceptet, som altså afspejler delta-0 i ligningen */
	
	* Risiko for ekspropriering
		reg d.ex1 d.aid d.oilcap d.polconiii d.w if period==6
		gen medtaget = 0
		replace medtaget = 1 if e(sample)==1

	* Beskrivende statistik på variable
		reg
		estat sum
		
		foreach v of varlist ex1 aid oilcap polconiii w {
			gen d_`v' = d.`v'
			la var d_`v' "ændring i `v' fra periode til periode"
		}
		
		hist d_ex1 if medtaget==1, scheme(s1mono) percent ytitle("procent" " ") xtitle(" " "ændring i risiko for ekspropriation")
			gr export "histogram_0.ps", replace logo(off)
			gr export "histogram_0.emf", replace

		hist d_aid if medtaget==1, scheme(s1mono) percent ytitle("procent" " ") xtitle(" " "ændring i ulandsbistand")
			gr export "histogram_1.ps", replace logo(off)
			gr export "histogram_1.emf", replace

		hist d_oilcap if medtaget==1, scheme(s1mono) percent ytitle("procent" " ") xtitle(" " "ændring i olieindtægter")
			gr export "histogram_2.ps", replace logo(off)
			gr export "histogram_2.emf", replace

		hist d_polconiii if medtaget==1, scheme(s1mono) percent ytitle("procent" " ") xtitle(" " "ændring i politiske rettigheder")
			gr export "histogram_3.ps", replace logo(off)
			gr export "histogram_3.emf", replace

		hist d_w if medtaget==1, scheme(s1mono) percent ytitle("procent" " ") xtitle(" " "ændring i regime-koalition")
			gr export "histogram_4.ps", replace logo(off)
			gr export "histogram_4.emf", replace

* Eksempel 3: Fixed effects
	* Eksempel på at FE og FD giver identiske resultater når hver enheder er observeret på to tidspunkter (eksempel 2)
		reg d.ex1 d.aid d.oilcap d.polconiii d.w if period==6
		xtreg ex1 aid oilcap polconiii w y6 if period==5 | period==6 & medtaget==1, fe
	
	* Eksempel på at FE og OLS-regression med dummy-variable for de øvre enheder (lande, ccid) giver identiske resultater
		xtreg ex1 aid oilcap polconiii w y6 if period==5 | period==6 & medtaget==1, fe
		reg ex1 aid oilcap polconiii w y6 i.ccid if period==5 | period==6 & medtaget==1

	* Kommunalpolitikeres lydhørhed
		* klargør data (tilføjer indbyggertal)
			/* use KVU1993, clear
				ren v247 komnr
				order komnr
				merge m:1 komnr using indbyggertal
					drop if _merge==2
					drop _merge
				
				saveold KVU1993, replace */
		
		use KVU1993, clear
		
		* kodninger
			gen kvinde = v178-1
				ta kvinde v178 /*  ok */

			recode v179 (5 6 = 0 "18-24 årige") (7 8 = 1 "25-34 årige") (9 10 11 = 2 "35-49 årige") (12 13 14 15 = 3 "50-64 årige") (16 17 18 = 4 "65+-årige"), gen(alder)
				la var alder "alder, kat."
				ta v179 alder
			
			gen viduddan = 0
				replace viduddan = 1 if v198==1 | v199==1 | v200==1
				la var viduddan "videregående uddannelse (1) eller ej (0)"
				tablist viduddan v198 v199 v200 , sort(v) /* ok */ /* NB: tablist er et tredjeparts-program som man selv skal installere: findit outreg2 */
			
			recode v152 (1 = 5 "Meget godt") (2 = 4 "Godt") (3 = 3 "Hverken godt eller dårligt") (4 = 2 "Dårligt") (5 = 1 "Meget dårligt"), gen(hvorgodt)
				la var hvorgodt "Hvor godt den nuværende borgmester har klaret sig på borgmesterposten"
				ta v152 hvorgodt /* ok */
			
			gen indb_1000 = indb / 1000
				la var indb_1000 "indbyggertal (tusinder)"
			
			gen ln_indb_1000 = ln(indb_1000)
				la var ln_indb_1000 "ln indbyggertal (tusinder)"
	
		* eksempel
			xtset komnr
			
			xtreg v40 ln_indb_1000 hvorgodt kvinde i.alder viduddan, fe
		
* Eksempel 4: Random effects
	xtreg v40 ln_indb_1000 hvorgodt kvinde i.alder viduddan, re

	* oversigtstabel
		reg v40 ln_indb_1000 hvorgodt kvinde i.alder viduddan, cluster(komnr)
			outreg2 using modeller, bdec(2) sdec(2) word cttop("OLS") replace /* NB: outreg2 er et tredjeparts-program som man selv skal installere: findit outreg2 */
		
		xtreg v40 ln_indb_1000 hvorgodt kvinde i.alder viduddan, fe
			outreg2 using modeller, bdec(2) sdec(2) word cttop("FE")
		
		xtreg v40 ln_indb_1000 hvorgodt kvinde i.alder viduddan, re
			outreg2 using modeller, bdec(2) sdec(2) word cttop("RE")
